@@ -14,20 +14,21 @@
 #    under the License.
 
 import mock
+from neutron_lib import context
 
-from neutron.common import constants
-from neutron import context
-from neutron.extensions import portbindings
-from neutron.extensions import providernet as pnet
 from neutron.plugins.ml2 import config
 from neutron.plugins.ml2 import managers
 from neutron.plugins.ml2 import rpc
 from neutron.tests.common import helpers
 from neutron.tests.unit.plugins.ml2 import test_plugin
+from neutron_lib.api.definitions import portbindings
+from neutron_lib.api.definitions import provider_net as pnet
 
 from networking_bagpipe.driver.type_route_target import TYPE_ROUTE_TARGET
 import networking_bagpipe.rpc.client as bagpipe_rpc
 
+from neutron_lib import constants as n_consts
+
 HOST = 'bagpipe_host'
 HOST_2 = HOST + '_2'
 HOST_3 = HOST + '_3'
@@ -42,7 +43,7 @@ def _get_linuxbridge_agent_dict(host, agent_type, binary,
     agent = {
         'binary': binary,
         'host': host,
-        'topic': constants.L2_AGENT_TOPIC,
+        'topic': n_consts.L2_AGENT_TOPIC,
         'agent_type': agent_type,
         'start_flag': True}
 
@@ -54,7 +55,7 @@ def _get_linuxbridge_agent_dict(host, agent_type, binary,
 
 
 def register_linuxbridge_agent(host=HOST,
-                               agent_type=constants.AGENT_TYPE_LINUXBRIDGE,
+                               agent_type=n_consts.AGENT_TYPE_LINUXBRIDGE,
                                binary='bagpipe-linuxbridge-agent',
                                bridge_mappings=None,
                                interface_mappings=None):
@@ -73,8 +74,7 @@ class TestBaGpipeRpcTestCase(test_plugin.Ml2PluginV2TestCase):
                                      'ml2')
         config.cfg.CONF.set_override('tenant_network_types',
                                      TYPE_ROUTE_TARGET,
-                                     'ml2',
-                                     enforce_type=True)
+                                     'ml2')
 
         super(TestBaGpipeRpcTestCase, self).setUp()
 
@@ -103,6 +103,10 @@ class TestBaGpipeRpcTestCase(test_plugin.Ml2PluginV2TestCase):
         cast_patch = mock.patch(cast)
         self.mock_cast = cast_patch.start()
 
+        # don't wait for DHCP provisioning block to clear
+        mock.patch('neutron.plugins.ml2.db.is_dhcp_active_on_any_subnet',
+                   return_value=False).start()
+
     def _register_ml2_agents(self):
         register_linuxbridge_agent(host=HOST)
         register_linuxbridge_agent(host=HOST_2)
